@@ -75,7 +75,9 @@ char run_id[128] = "",
   rellBootstrapFileName[1024] = "",
   rellBootstrapFileNamePID[1024] = "",
   mesquiteModel[1024] = "",
-  mesquiteTrees[1024] = "";
+  mesquiteTrees[1024] = "",
+  mesquiteMLTrees[1024]="",
+  mesquiteMLLikes[1024] = "";
 
 
 
@@ -83,7 +85,7 @@ char run_id[128] = "",
 
 char *protModels[NUM_PROT_MODELS] = {"DAYHOFF", "DCMUT", "JTT", "MTREV", "WAG", "RTREV", "CPREV", "VT", 
 				     "BLOSUM62", "MTMAM", "LG", "MTART", "MTZOA", "PMB", "HIVB", "HIVW", 
-				     "JTTDCMUT", "FLU",  "DUMMY", "DUMMY2", "AUTO", "LG4M", "LG4X", "PROT_FILE", "GTR_UNLINKED", "GTR"};
+				     "JTTDCMUT", "FLU",  "STMTREV", "DUMMY", "DUMMY2", "AUTO", "LG4M", "LG4X", "PROT_FILE", "GTR_UNLINKED", "GTR"};
 
 const char binaryStateNames[2]   = {'0', '1'};
 const char dnaStateNames[4]      = {'A', 'C', 'G', 'T'};
